@@ -4,9 +4,11 @@ use strict;
 use warnings;
 
 use Carp;
+use Exporter;
 use List::MoreUtils 'natatime';
 
-my @EXPORT_OK = qw/
+our @ISA = qw/Exporter/;
+our @EXPORT_OK = qw/
     validate
     filter
     is_required
@@ -20,19 +22,11 @@ my @EXPORT_OK = qw/
     is_in
 /;
 
-sub import {
-    my $class = shift;
-    my $caller = caller;
-    my @rest = _match(':all', \@_) ? @EXPORT_OK : @_;
-    no strict 'refs';
-    for my $sub ( @rest ) {
-        if ( _match($sub, \@EXPORT_OK) ) {
-            *{"${caller}::$sub"} = eval("\\\&$sub");
-        }
-    }
-}
+our %EXPORT_TAGS = (
+    'all' => \@EXPORT_OK
+);
 
-our $VERSION = '1.005';
+our $VERSION = '1.015';
 
 sub validate {
     my ( $input, $rules ) = @_;
@@ -40,9 +34,7 @@ sub validate {
 
     # Sanity check
     #
-    if ( !defined $rules->{fields} ) {
-        die 'You must define a fields array';
-    }
+    die 'You must define a fields array' unless defined $rules->{fields};
 
     for (qw/filters checks/) {
         next unless exists $rules->{$_};
@@ -52,9 +44,7 @@ sub validate {
     }
 
     for ( keys %$rules ) {
-        if ( $_ ne 'fields' && $_ ne 'filters' && $_ ne 'checks' ) {
-            die "Unknown key $_";
-        }
+        /(fields|filters|checks)/ or die "Unknown key $_";
     }
 
     my $param = {};
@@ -63,9 +53,7 @@ sub validate {
     # Add existing, filtered input to $param
     #
     for my $key ( @fields ) {
-        if ( exists $input->{$key} ) {
-            $param->{$key} = _process( $rules->{filters}, $input, $key );
-        }
+        exists $input->{$key} and ($param->{$key} = _process( $rules->{filters}, $input, $key ));
     }
 
     # Process all checks for $param
@@ -86,11 +74,12 @@ sub validate {
 sub _run_code {
     my ( $code, $value, $param, $key ) = @_;
     my $result = $value;
-    if ( ref $code eq 'CODE' ) {
+    my $ref = ref $code;
+    if ( $ref eq 'CODE' ) {
         $result = $code->( $value, $param, $key );
         $value = $result unless defined $param;
     }
-    elsif ( ref $code eq 'ARRAY' ) {
+    elsif ( $ref eq 'ARRAY' ) {
         for (@$code) {
             $result = _run_code( $_, $value, $param, $key );
             if ( defined $param ) {
@@ -144,7 +133,7 @@ sub _match {
 
 sub filter {
     my $FILTERS = {
-        trim    => sub { $_[0] =~ s/^\s+//; $_[0] =~ s/\s+$//; $_[0] },
+        trim    => sub { $_[0] =~ s/^\s+//; $_[0] =~ s/\s+$//; $_[0]  },
         strip   => sub { $_[0] =~ s/(\s){2,}/$1/g; $_[0] },
         lc      => sub { lc $_[0] },
         uc      => sub { uc $_[0] },
@@ -291,10 +280,10 @@ sub AUTOLOAD {
     my $self = shift;
     our $AUTOLOAD;
     my $sub = $AUTOLOAD =~ /::(\w+)$/ ? $1 : undef;
-    if ( $sub eq 'params' || $sub eq 'rules' ) {
+    if ( $sub =~ /(params|rules)/ ) {
         return $self->{$sub};
     }
-    elsif ( $sub eq 'data' || $sub eq 'error' ) {
+    elsif ( $sub =~ /(data|error)/ ) {
         if ( my $field = shift ) {
             my $fields = $self->{rules}->{fields};
             if ( scalar(@$fields) ) {
@@ -1018,10 +1007,11 @@ https://github.com/naturalist/Validate--Tiny
 
 =head1 AUTHOR
 
-    minimalist (cpan: MINIMAL) - minimalist@lavabit.com
+    miniml (cpan: MINIMAL) - minimal@cpan.org
 
 =head1 CONTRIBUTORS
 
+    Patrice Clement (cpan: MONSIEUR) - monsieurp@gentoo.org
     Viktor Turskyi (cpan: KOORCHIK) - koorchik@cpan.org
     Ivan Simonik (cpan: SIMONIKI) - simoniki@cpan.org
 
